@@ -415,14 +415,14 @@ void CollectionCheckListModel::slotRowsInserted(const QModelIndex& parent, int s
 void CollectionCheckListModel::selectionChanged(const QItemSelection& selected, const QItemSelection& deselected)
 {
     const QModelIndexList sel = selected.indexes();
-    foreach (const QModelIndex& ix, sel)
+    for (const QModelIndex& ix : sel)
     {
         // Try to enable the collection, but untick it if not possible
         if (!CollectionControlModel::setEnabled(mModel->collection(ix), mAlarmType, true))
             mSelectionModel->select(ix, QItemSelectionModel::Deselect);
     }
     const QModelIndexList desel = deselected.indexes();
-    foreach (const QModelIndex& ix, desel)
+    for (const QModelIndex& ix : desel)
         CollectionControlModel::setEnabled(mModel->collection(ix), mAlarmType, false);
 }
 
@@ -618,7 +618,7 @@ bool CollectionView::viewportEvent(QEvent* e)
         const QHelpEvent* he = static_cast<QHelpEvent*>(e);
         const QModelIndex index = indexAt(he->pos());
         QVariant value = static_cast<CollectionFilterCheckListModel*>(model())->data(index, Qt::ToolTipRole);
-        if (qVariantCanConvert<QString>(value))
+        if (value.canConvert<QString>())
         {
             QString toolTip = value.toString();
             int i = toolTip.indexOf(QLatin1Char('@'));
@@ -687,9 +687,12 @@ CollectionControlModel::CollectionControlModel(QObject* parent)
     EntityMimeTypeFilterModel* filter = new EntityMimeTypeFilterModel(this);
     filter->addMimeTypeInclusionFilter(Collection::mimeType());
     filter->setSourceModel(AkonadiModel::instance());
-    Collection::List collections;
-    findEnabledCollections(filter, QModelIndex(), collections);
-    setCollections(collections);
+
+    QList<Collection::Id> collectionIds;
+    findEnabledCollections(filter, QModelIndex(), collectionIds);
+    setCollections(Collection::List());
+    for (Collection::Id id : qAsConst(collectionIds))
+        addCollection(Collection(id));
 
     connect(AkonadiModel::instance(), &AkonadiModel::collectionStatusChanged,
                                       this, &CollectionControlModel::statusChanged);
@@ -706,7 +709,7 @@ CollectionControlModel::CollectionControlModel(QObject* parent)
 * Collections which duplicate the same backend storage are filtered out, to
 * avoid crashes due to duplicate events in different resources.
 */
-void CollectionControlModel::findEnabledCollections(const EntityMimeTypeFilterModel* filter, const QModelIndex& parent, Collection::List& collections) const
+void CollectionControlModel::findEnabledCollections(const EntityMimeTypeFilterModel* filter, const QModelIndex& parent, QList<Collection::Id>& collectionIds) const
 {
     AkonadiModel* model = AkonadiModel::instance();
     for (int row = 0, count = filter->rowCount(parent);  row < count;  ++row)
@@ -717,7 +720,7 @@ void CollectionControlModel::findEnabledCollections(const EntityMimeTypeFilterMo
             continue;    // the collection doesn't belong to a resource, so omit it
         const CalEvent::Types enabled = !collection.hasAttribute<CollectionAttribute>() ? CalEvent::EMPTY
                                            : collection.attribute<CollectionAttribute>()->enabled();
-        const CalEvent::Types canEnable = checkTypesToEnable(collection, collections, enabled);
+        const CalEvent::Types canEnable = checkTypesToEnable(collection, collectionIds, enabled);
         if (canEnable != enabled)
         {
             // There is another collection which uses the same backend
@@ -726,12 +729,15 @@ void CollectionControlModel::findEnabledCollections(const EntityMimeTypeFilterMo
                 model->setData(model->collectionIndex(collection), static_cast<int>(canEnable), AkonadiModel::EnabledTypesRole);
         }
         if (canEnable)
-            collections += collection;
+            collectionIds += collection.id();
         if (filter->rowCount(ix) > 0)
-            findEnabledCollections(filter, ix, collections);
+            findEnabledCollections(filter, ix, collectionIds);
     }
 }
 
+/******************************************************************************
+* Return whether a collection is enabled for a given alarm type.
+*/
 bool CollectionControlModel::isEnabled(const Collection& collection, CalEvent::Type type)
 {
     if (!collection.isValid()  ||  !instance()->collectionIds().contains(collection.id()))
@@ -778,18 +784,17 @@ CalEvent::Types CollectionControlModel::setEnabled(const Collection& collection,
 CalEvent::Types CollectionControlModel::setEnabledStatus(const Collection& collection, CalEvent::Types types, bool inserted)
 {
     qCDebug(KALARM_LOG) << "CollectionControlModel::setEnabledStatus:" << collection.id() << ", types=" << types;
-    CalEvent::Types disallowedStdTypes(0);
-    CalEvent::Types stdTypes(0);
+    CalEvent::Types disallowedStdTypes{};
+    CalEvent::Types stdTypes{};
 
     // Prevent the enabling of duplicate alarm types if another collection
     // uses the same backend storage.
-    const Collection::List cols = collections();
-    const CalEvent::Types canEnable = checkTypesToEnable(collection, cols, types);
+    const QList<Collection::Id> colIds = collectionIds();
+    const CalEvent::Types canEnable = checkTypesToEnable(collection, colIds, types);
 
     // Update the list of enabled collections
     if (canEnable)
     {
-        const QList<Collection::Id> colIds = collectionIds();
         if (!colIds.contains(collection.id()))
         {
             // It's a new collection.
@@ -799,7 +804,7 @@ CalEvent::Types CollectionControlModel::setEnabledStatus(const Collection& colle
                                 : CalEvent::EMPTY;
             if (stdTypes)
             {
-                foreach (const Collection::Id& id, colIds)
+                for (const Collection::Id& id : colIds)
                 {
                     Collection c(id);
                     AkonadiModel::instance()->refresh(c);    // update with latest data
@@ -919,22 +924,23 @@ void CollectionControlModel::statusChanged(const Collection& collection, Akonadi
 * collection. This is to avoid duplicating events between different resources,
 * which causes user confusion and annoyance, and causes crashes.
 * Parameters:
-*   collection  - must be up to date (using AkonadiModel::refresh() etc.)
-*   collections = list of collections to search for duplicates.
-*   types       = alarm types to be enabled for the collection.
+*   collection    - must be up to date (using AkonadiModel::refresh() etc.)
+*   collectionIds = list of collection IDs to search for duplicates.
+*   types         = alarm types to be enabled for the collection.
 * Reply = alarm types which can be enabled without duplicating other collections.
 */
-CalEvent::Types CollectionControlModel::checkTypesToEnable(const Collection& collection, const Collection::List& collections, CalEvent::Types types)
+CalEvent::Types CollectionControlModel::checkTypesToEnable(const Collection& collection, const QList<Collection::Id>& collectionIds, CalEvent::Types types)
 {
     types &= (CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE);
     if (types)
     {
         // At least one alarm type is to be enabled
         const QUrl location = QUrl::fromUserInput(collection.remoteId(), QString(), QUrl::AssumeLocalFile);
-        foreach (const Collection& c, collections)
+        for (const Collection::Id& id : collectionIds)
         {
+            const Collection c(id);
             const QUrl cLocation = QUrl::fromUserInput(c.remoteId(), QString(), QUrl::AssumeLocalFile);
-            if (c.id() != collection.id()  &&  cLocation == location)
+            if (id != collection.id()  &&  cLocation == location)
             {
                 // The collection duplicates the backend storage
                 // used by another enabled collection.
@@ -999,13 +1005,13 @@ int CollectionControlModel::isWritableEnabled(const Akonadi::Collection& collect
 
 /******************************************************************************
 * Return the standard collection for a specified mime type.
-* If 'useDefault' is true and there is no standard collection, the only
-* collection for the mime type will be returned as a default.
+* If the mime type is 'archived' and there is no standard collection, the only
+* writable archived collection is set to be the standard.
 */
-Collection CollectionControlModel::getStandard(CalEvent::Type type, bool useDefault)
+Collection CollectionControlModel::getStandard(CalEvent::Type type)
 {
     const QString mimeType = CalEvent::mimeType(type);
-    int defalt = -1;
+    int defaultArch = -1;
     const QList<Collection::Id> colIds = instance()->collectionIds();
     Collection::List cols;
     for (int i = 0, count = colIds.count();  i < count;  ++i)
@@ -1020,10 +1026,20 @@ Collection CollectionControlModel::getStandard(CalEvent::Type type, bool useDefa
             &&  (col.attribute<CollectionAttribute>()->standard() & type)
             &&  AkonadiModel::isCompatible(col))
                 return col;
-            defalt = (defalt == -1) ? i : -2;
+            if (type == CalEvent::ARCHIVED  &&  ((col.rights() & writableRights) == writableRights))
+                defaultArch = (defaultArch == -1) ? i : -2;
         }
     }
-    return (useDefault && defalt >= 0) ? cols[defalt] : Collection();
+
+    if (defaultArch >= 0)
+    {
+        // There is no standard collection for archived alarms, but there is
+        // only one writable collection for the type. Set the collection to be
+        // the standard.
+        setStandard(cols[defaultArch], type, true);
+        return cols[defaultArch];
+    }
+    return Collection();
 }
 
 /******************************************************************************
@@ -1032,6 +1048,10 @@ Collection CollectionControlModel::getStandard(CalEvent::Type type, bool useDefa
 */
 bool CollectionControlModel::isStandard(Akonadi::Collection& collection, CalEvent::Type type)
 {
+    // If it's for archived alarms, set the standard collection if necessary.
+    if (type == CalEvent::ARCHIVED)
+        return getStandard(type) == collection;
+
     if (!instance()->collectionIds().contains(collection.id()))
         return false;
     AkonadiModel::instance()->refresh(collection);    // update with latest data
@@ -1240,6 +1260,28 @@ Collection CollectionControlModel::destination(CalEvent::Type type, QWidget* pro
     return col;
 }
 
+/******************************************************************************
+* Return all collections which belong to a resource and which optionally
+* contain a specified mime type.
+*/
+Collection::List CollectionControlModel::allCollections(CalEvent::Type type)
+{
+    const bool allTypes = (type == CalEvent::EMPTY);
+    const QString mimeType = CalEvent::mimeType(type);
+    AgentManager* agentManager = AgentManager::self();
+    Collection::List result;
+    const QList<Collection::Id> colIds = instance()->collectionIds();
+    for (Collection::Id id : colIds)
+    {
+        Collection c(id);
+        AkonadiModel::instance()->refresh(c);    // update with latest data
+        if ((allTypes  ||  c.contentMimeTypes().contains(mimeType))
+        &&  agentManager->instance(c.resource()).isValid())
+            result += c;
+    }
+    return result;
+}
+
 /******************************************************************************
 * Return the enabled collections which contain a specified mime type.
 * If 'writable' is true, only writable collections are included.
@@ -1265,11 +1307,12 @@ Collection::List CollectionControlModel::enabledCollections(CalEvent::Type type,
 */
 Collection CollectionControlModel::collectionForResource(const QString& resourceId)
 {
-    const Collection::List cols = instance()->collections();
-    for (int i = 0, count = cols.count();  i < count;  ++i)
+    const QList<Collection::Id> colIds = instance()->collectionIds();
+    for (Collection::Id id : colIds)
     {
-        if (cols[i].resource() == resourceId)
-            return cols[i];
+        Collection c(id);
+        if (c.resource() == resourceId)
+            return c;
     }
     return Collection();
 }
