@@ -214,12 +214,12 @@ class CollectionControlModel : public Akonadi::FavoriteCollectionsModel
         static int isWritableEnabled(const Akonadi::Collection& collection, CalEvent::Type type, KACalendar::Compat& format);
 
         /** Return the standard collection for a specified mime type.
-         *  @param type       The mime type
-         *  @param useDefault false to return the defined standard collection, if any;
-         *                    true to return the standard or only collection for the type.
+         *  If the mime type is 'archived' and there is no standard collection, the
+         *  only writable archived collection is set to be the standard.
+         *  @param type  The mime type
          *  Reply = invalid collection if there is no standard collection.
          */
-        static Akonadi::Collection getStandard(CalEvent::Type type, bool useDefault = false);
+        static Akonadi::Collection getStandard(CalEvent::Type type);
 
         /** Return whether a collection is the standard collection for a specified
          *  mime type. */
@@ -260,6 +260,12 @@ class CollectionControlModel : public Akonadi::FavoriteCollectionsModel
          */
         static Akonadi::Collection destination(CalEvent::Type type, QWidget* promptParent = nullptr, bool noPrompt = false, bool* cancelled = nullptr);
 
+        /** Return a list of all collections, both enabled and disabled.
+         *  Collections which don't belong to a resource are omitted.
+         *  @param type  Return only collections for this event type, or EMPTY for all.
+         */
+        static Akonadi::Collection::List allCollections(CalEvent::Type type = CalEvent::EMPTY);
+
         /** Return the enabled collections which contain a specified mime type.
          *  If 'writable' is true, only writable collections are included.
          */
@@ -295,9 +301,9 @@ class CollectionControlModel : public Akonadi::FavoriteCollectionsModel
 
     private:
         explicit CollectionControlModel(QObject* parent = nullptr);
-        void findEnabledCollections(const Akonadi::EntityMimeTypeFilterModel*, const QModelIndex& parent, Akonadi::Collection::List&) const;
+        void findEnabledCollections(const Akonadi::EntityMimeTypeFilterModel*, const QModelIndex& parent, QList<Akonadi::Collection::Id>&) const;
         CalEvent::Types setEnabledStatus(const Akonadi::Collection&, CalEvent::Types, bool inserted);
-        static CalEvent::Types checkTypesToEnable(const Akonadi::Collection&, const Akonadi::Collection::List&, CalEvent::Types);
+        static CalEvent::Types checkTypesToEnable(const Akonadi::Collection&, const QList<Akonadi::Collection::Id>&, CalEvent::Types);
 
         static CollectionControlModel* mInstance;
         static bool mAskDestination;
