@@ -42,7 +42,7 @@ TimeEdit::TimeEdit(QWidget* parent)
       mReadOnly(false)
 {
     QHBoxLayout* layout = new QHBoxLayout;
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
     setLayout(layout);
     bool use12hour = use12HourClock();
