@@ -1,7 +1,7 @@
 /*
  *  messagewin.cpp  -  displays an alarm message
  *  Program:  kalarm
- *  Copyright © 2001-2019 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -59,14 +59,13 @@
 #include <kwindowinfo.h>
 #include <netwm.h>
 #include <qx11info_x11.h>
+#include <QScreen>
 #endif
 
 #include <QTextBrowser>
 #include <QPushButton>
 #include <QScrollBar>
 #include <QLocale>
-#include <QtDBus>
-#include <QFile>
 #include <QCheckBox>
 #include <QLabel>
 #include <QPalette>
@@ -395,7 +394,8 @@ void MessageWin::initView()
     QWidget* topWidget = new QWidget(this);
     setCentralWidget(topWidget);
     QVBoxLayout* topLayout = new QVBoxLayout(topWidget);
-    topLayout->setMargin(style()->pixelMetric(QStyle::PM_DefaultChildMargin));
+    int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
+    topLayout->setContentsMargins(dcm, dcm, dcm, dcm);
     topLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     QPalette labelPalette = palette();
@@ -568,7 +568,7 @@ void MessageWin::initView()
             // Advance reminder: show remaining time until the actual alarm
             mRemainingText = new QLabel(topWidget);
             mRemainingText->setFrameStyle(QFrame::Box | QFrame::Raised);
-            mRemainingText->setMargin(leading);
+            mRemainingText->setContentsMargins(leading, leading, leading, leading);
             mRemainingText->setPalette(labelPalette);
             mRemainingText->setAutoFillBackground(true);
             if (mDateTime.isDateOnly()  ||  KADateTime::currentLocalDate().daysTo(mDateTime.date()) > 0)
@@ -599,7 +599,7 @@ void MessageWin::initView()
                 frame->setWhatsThis(i18nc("@info:whatsthis", "The email to send"));
                 topLayout->addWidget(frame, 0, Qt::AlignHCenter);
                 QGridLayout* grid = new QGridLayout(frame);
-                grid->setMargin(style()->pixelMetric(QStyle::PM_DefaultChildMargin));
+                grid->setContentsMargins(dcm, dcm, dcm, dcm);
                 grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
                 QLabel* label = new QLabel(i18nc("@info Email addressee", "To:"), frame);
@@ -637,7 +637,8 @@ void MessageWin::initView()
     {
         setCaption(i18nc("@title:window", "Error"));
         QHBoxLayout* layout = new QHBoxLayout();
-        layout->setMargin(2 * style()->pixelMetric(QStyle::PM_DefaultChildMargin));
+        int m = 2 * dcm;
+        layout->setContentsMargins(m, m, m, m);
         layout->addStretch();
         topLayout->addLayout(layout);
         QLabel* label = new QLabel(topWidget);
@@ -780,7 +781,7 @@ int MessageWin::instanceCount(bool excludeAlwaysHidden)
     int count = mWindowList.count();
     if (excludeAlwaysHidden)
     {
-        foreach (MessageWin* win, mWindowList)
+        for (MessageWin* win : qAsConst(mWindowList))
         {
             if (win->mAlwaysHide)
                 --count;
@@ -873,8 +874,10 @@ QString MessageWin::dateTimeToDisplay()
                 local.setTimeSpec(KADateTime::Spec::LocalZone());
                 showZone = (local.toString(QStringLiteral("%Z")) != tz);
             }
-#pragma message("port QT5")
-            tm = QLocale().toString(mDateTime.qDateTime(), QLocale::ShortFormat); // KLocale::DateTimeFormatOptions(showZone ? KLocale::TimeZone : 0));
+            const QDateTime dt = mDateTime.qDateTime();
+            tm = QLocale().toString(dt, QLocale::ShortFormat);
+            if (showZone)
+                tm += QLatin1Char(' ') + mDateTime.timeZone().displayName(dt, QTimeZone::ShortName, QLocale());
         }
     }
     return tm;
@@ -1758,6 +1761,7 @@ QSize MessageWin::sizeHint() const
                 break;
             }
             // fall through to default
+            Q_FALLTHROUGH();
         default:
             return MainWindowBase::sizeHint();
     }
@@ -2258,22 +2262,22 @@ bool MessageWin::getWorkAreaAndModal()
     mScreenNumber = -1;
     const bool modal = Preferences::modalMessages();
 #if KDEPIM_HAVE_X11
-    const QDesktopWidget* desktop = qApp->desktop();
-    const int numScreens = desktop->numScreens();
+    const QList<QScreen*> screens = QGuiApplication::screens();
+    const int numScreens = screens.count();
     if (numScreens > 1)
     {
         // There are multiple screens.
         // Check for any full screen windows, even if they are not the active
         // window, and try not to show the alarm message their screens.
-        mScreenNumber = desktop->screenNumber(MainWindow::mainMainWindow());  // default = KAlarm's screen
-        if (desktop->isVirtualDesktop())
+        mScreenNumber = QApplication::desktop()->screenNumber(MainWindow::mainMainWindow());  // default = KAlarm's screen
+        if (QGuiApplication::primaryScreen()->virtualSiblings().size() > 1)
         {
             // The screens form a single virtual desktop.
             // Xinerama, for example, uses this scheme.
             QVector<FullScreenType> screenTypes(numScreens);
             QVector<QRect> screenRects(numScreens);
             for (int s = 0;  s < numScreens;  ++s)
-                screenRects[s] = desktop->screenGeometry(s);
+                screenRects[s] = screens[s]->geometry();
             const FullScreenType full = findFullScreenWindows(screenRects, screenTypes);
             if (full == NoFullScreen  ||  screenTypes[mScreenNumber] == NoFullScreen)
                 return modal;
@@ -2303,7 +2307,7 @@ bool MessageWin::getWorkAreaAndModal()
             // The screens are completely separate from each other.
             int inactiveScreen = -1;
             FullScreenType full = haveFullScreenWindow(mScreenNumber);
-qCDebug(KALARM_LOG)<<"full="<<full<<", screen="<<mScreenNumber;
+//qCDebug(KALARM_LOG)<<"full="<<full<<", screen="<<mScreenNumber;
             if (full == NoFullScreen)
                 return modal;   // KAlarm's screen doesn't contain a full screen window
             if (full == FullScreen)
@@ -2358,23 +2362,16 @@ FullScreenType haveFullScreenWindow(int screen)
     const xcb_window_t activeWindow = rootInfo.activeWindow();
     const xcb_window_t* windows     = rootInfo.clientList();
     const int windowCount           = rootInfo.clientListCount();
-qCDebug(KALARM_LOG)<<"Screen"<<screen<<": Window count="<<windowCount<<", active="<<activeWindow<<", geom="<<qApp->desktop()->screenGeometry(screen);
-NETRect geom;
-NETRect frame;
     for (int w = 0;  w < windowCount;  ++w)
     {
         NETWinInfo winInfo(connection, windows[w], rootWindow, NET::WMState|NET::WMGeometry, NET::Properties2());
-winInfo.kdeGeometry(frame, geom);
-const QRect fr(frame.pos.x, frame.pos.y, frame.size.width, frame.size.height);
-const QRect gm(geom.pos.x, geom.pos.y, geom.size.width, geom.size.height);
         if (winInfo.state() & NET::FullScreen)
         {
-qCDebug(KALARM_LOG)<<"Found FULL SCREEN: "<<windows[w]<<", geom="<<gm<<", frame="<<fr;
+//qCDebug(KALARM_LOG)<<"Found FULL SCREEN: " << windows[w];
             type = FullScreen;
             if (windows[w] == activeWindow)
                 return FullScreenActive;
         }
-//else { qCDebug(KALARM_LOG)<<"Found normal: "<<windows[w]<<", geom="<<gm<<", frame="<<fr; }
     }
     return type;
 }
@@ -2393,7 +2390,7 @@ FullScreenType findFullScreenWindows(const QVector<QRect>& screenRects, QVector<
     const xcb_window_t activeWindow = rootInfo.activeWindow();
     const xcb_window_t* windows     = rootInfo.clientList();
     const int windowCount           = rootInfo.clientListCount();
-qCDebug(KALARM_LOG)<<"Virtual desktops: Window count="<<windowCount<<", active="<<activeWindow<<", geom="<<qApp->desktop()->screenGeometry(0);
+//qCDebug(KALARM_LOG)<<"Virtual desktops: Window count="<<windowCount<<", active="<<activeWindow<<", geom="<<QApplication::desktop()->screenGeometry(0);
     NETRect netgeom;
     NETRect netframe;
     for (int w = 0;  w < windowCount;  ++w)
@@ -2405,12 +2402,12 @@ qCDebug(KALARM_LOG)<<"Virtual desktops: Window count="<<windowCount<<", active="
             const bool active = (windows[w] == activeWindow);
             winInfo.kdeGeometry(netframe, netgeom);
             const QRect winRect(netgeom.pos.x, netgeom.pos.y, netgeom.size.width, netgeom.size.height);
-qCDebug(KALARM_LOG)<<"Found FULL SCREEN: "<<windows[w]<<", geom="<<winRect;
+//qCDebug(KALARM_LOG)<<"Found FULL SCREEN: "<<windows[w]<<", geom="<<winRect;
             for (int s = 0, count = screenRects.count();  s < count;  ++s)
             {
                 if (screenRects[s].contains(winRect))
                 {
-qCDebug(KALARM_LOG)<<"FULL SCREEN on screen"<<s<<", active="<<active;
+//qCDebug(KALARM_LOG)<<"FULL SCREEN on screen"<<s<<", active="<<active;
                     if (active)
                         screenTypes[s] = result = FullScreenActive;
                     else
